/* Define this to be the name of the package */
#undef PACKAGE

/* Define to the version of the package */
#undef VERSION

/* Define to 'int8_t' if not defined anywhere. */
#undef __s8

/* Define to 'u_int8_t' if not defined anywhere. */
#undef __u8

/* Define to 'int16_t' if not defined anywhere. */
#undef __s16

/* Define to 'u_int16_t' if not defined anywhere. */
#undef __u16

/* Define to 'int32_t' if not defined anywhere. */
#undef __s32

/* Define to 'u_int32_t' if not defined anywhere. */
#undef __u32

/* Define to 'unsigned' if <sys/types.h> doesn't define. */
#undef loff_t

/* Define iff <linux/ext2_fs.h> has a struct ext2_dir_entry_2. */
#undef HAVE_EXT2_DIR_ENTRY_2
